@@ -38,11 +38,12 @@ class Logger:
                 source = source.replace('venv\\lib\\site-packages\\','')
                 source = source.replace('Windows\\system32\\','')
 
-            if not user is None:
-                os.environ['AWS_PROFILENAME'] = user
+            if not user is None:                
+                Logger.user = user
             else:
-                user = os.environ['AWS_PROFILENAME']
-            Logger.user = user
+                user = 'guest'
+                Logger.user = 'guest'
+            
             
             source = source.lstrip('src').lstrip('\\src')
             source = source.lstrip('\\').lstrip('/')        
@@ -84,7 +85,7 @@ class Logger:
             self.log.addHandler(fhandler)
             #log to aws kinesis
             kinesishandler = KinesisLogStreamHandler(user=Logger.user)
-            kinesishandler.setLevel(logging.DEBUG)
+            kinesishandler.setLevel(loglevel)
             jsonformatter = JsonFormatter(os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME'] + 
                 ';%(asctime)s;%(name)s;%(levelname)s;%(message)s',\
                 datefmt='%Y-%m-%dT%H:%M:%S%z')
@@ -93,10 +94,10 @@ class Logger:
             #assign static variable log to be used by modules
             Logger.log = self.log
             try:
-                Logger.log.debug('Logger initialized shareddata user %s version %s!' % \
+                Logger.log.info('Logger initialized shareddata user %s version %s!' % \
                     (Logger.user,version('SharedData')))
             except:
-                Logger.log.debug('Logger initialized shareddata!')
+                Logger.log.info('Logger initialized shareddata!')
         
     def readLogs(self):    
         logsdir = Path(os.environ['LOG_PATH']).parents[0]
