@@ -27,8 +27,7 @@ class SharedDataFrame:
         
         self.sharedDataFeeder = sharedDataPeriod.sharedDataFeeder
         self.feeder = sharedDataPeriod.sharedDataFeeder.feeder
-        self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData
-        self.debug = self.sharedData.debug
+        self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData        
         self.database = self.sharedData.database
 
         self.period = sharedDataPeriod.period
@@ -79,7 +78,7 @@ class SharedDataFrame:
     # C R U D
     def Malloc(self, df=None):
         tini=time.time()
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Malloc %s/%s/%s/%s ...%.2f%% ' % \
                 (self.database,self.feeder,self.period,self.tagstr,0.0))      
 
@@ -112,7 +111,7 @@ class SharedDataFrame:
                         'columns': self.data.columns.values.tolist()                                 
                         }
                     json.dump(shm_info, outfile, indent=3)
-                if self.debug:
+                if os.environ['LOG_LEVEL']=='DEBUG':
                     Logger.log.debug('Malloc create %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
                         (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
 
@@ -143,7 +142,7 @@ class SharedDataFrame:
                         iidx = df.index.intersection(self.data.index)
                         icol = df.columns.intersection(self.data.columns)
                         self.data.loc[iidx, icol] = df.loc[iidx, icol].copy()
-                    if self.debug:
+                    if os.environ['LOG_LEVEL']=='DEBUG':
                         Logger.log.debug('Malloc map %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
                             (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                    
                     return True
@@ -159,7 +158,7 @@ class SharedDataFrame:
         npypath = path / (self.tagstr+'.npy')
             
         if (jsonpath.is_file()) & (npypath.is_file()):
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Reading %s/%s/%s ...%.2f%% ' % \
                     (self.feeder,self.period,self.tagstr,0.0))  
             with open(str(jsonpath), 'r') as infile:
@@ -175,7 +174,7 @@ class SharedDataFrame:
                     df = pd.DataFrame(values,\
                         index=_index,\
                         columns=_columns)
-                    if self.debug:
+                    if os.environ['LOG_LEVEL']=='DEBUG':
                         Logger.log.debug('Reading %s/%s/%s/%s ...%.2f%% %.2f sec! ' % \
                             (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
                     return df
@@ -187,7 +186,7 @@ class SharedDataFrame:
 
     def Write(self,startDate=None):
         tini = time.time()
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Writing %s/%s/%s/%s  ...%.2f%% ' % \
                 (self.database,self.feeder,self.period,self.tagstr,0.0))        
 
@@ -201,15 +200,17 @@ class SharedDataFrame:
                 'columns': self.data.columns.values.tolist()                                 
                 }
             json.dump(shm_info, outfile, indent=3)
+            outfile.flush()
 
-        if self.sharedData.s3write:
-            S3Upload(jsonpath)
+        with open(str(npypath), 'wb') as f:
+            np.save(f,self.data.values.astype(np.float64))
+            f.flush()
 
-        np.save(str(npypath),self.data.values.astype(np.float64))
         if self.sharedData.s3write:
             S3Upload(npypath)
+            S3Upload(jsonpath)
 
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Writing %s/%s/%s/%s ...%.2f%% %.2f sec!' % \
                 (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))
         
