@@ -16,8 +16,6 @@ class SharedDataPeriod:
         self.sharedDataFeeder = sharedDataFeeder        
         self.sharedData = sharedDataFeeder.sharedData        
         self.period = period
-        self.default_startDate = None
-        self.default_collections = None
         
         # PRE REGISTERED TAGS
         self.dataset = pd.DataFrame([])
@@ -36,11 +34,14 @@ class SharedDataPeriod:
         self.timeidx = {}
         self.ctimeidx = {}        
         if self.period=='D1':
-            self.periodSeconds = 60*60*24            
+            self.periodSeconds = 60*60*24       
+            self.default_startDate = pd.Timestamp('2000-01-01')
         elif self.period=='M15':
             self.periodSeconds = 60*15
+            self.default_startDate = pd.Timestamp('2000-01-01')
         elif self.period=='M1':
             self.periodSeconds = 60
+            self.default_startDate = pd.Timestamp('2010-01-01')
 
     def __setitem__(self, tag, df):
         if not tag in self.tags.keys():
