@@ -24,8 +24,7 @@ class SharedDataTimeSeries:
         self.tag = tag
         
         self.sharedDataFeeder = sharedDataPeriod.sharedDataFeeder
-        self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData
-        self.debug = self.sharedData.debug
+        self.sharedData = sharedDataPeriod.sharedDataFeeder.sharedData        
 
         self.period = sharedDataPeriod.period
         self.periodSeconds = sharedDataPeriod.periodSeconds               
@@ -187,7 +186,7 @@ class SharedDataTimeSeries:
         #Create write ndarray
         path, shm_name = self.getDataPath()
         fpath = path / ('shm_info.json')
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Malloc %s ...%.2f%% ' % (shm_name,0.0))
 
         file_exists = False
@@ -223,7 +222,7 @@ class SharedDataTimeSeries:
                     }
                 json.dump(shm_info, outfile, indent=3)
             
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Malloc create %s ...%.2f%% %.2f sec! ' % \
                     (shm_name,100,time.time()-tini))            
 
@@ -255,7 +254,7 @@ class SharedDataTimeSeries:
                     icol = value.columns.intersection(self.data.columns)
                     self.data.loc[iidx, icol] = value.loc[iidx, icol]
 
-                if self.debug:
+                if os.environ['LOG_LEVEL']=='DEBUG':
                     Logger.log.debug('Malloc map %s/%s/%s ...%.2f%% %.2f sec! ' % \
                         (self.feeder,self.period,self.tag,100,time.time()-tini))      
         return False
@@ -270,11 +269,11 @@ class SharedDataTimeSeries:
         nfiles = len(files.index)
         if nfiles>0:
             tini=time.time()
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Reading %s ...%.2f%% ' % (shm_name,0.0))   
             n=0
             self.read_multithread(files['fpath'])
-            if self.debug:
+            if os.environ['LOG_LEVEL']=='DEBUG':
                 Logger.log.debug('Reading %s ...%.2f%% %.2f sec! ' % \
                     (shm_name,100*(n/nfiles),time.time()-tini))
 
@@ -320,7 +319,7 @@ class SharedDataTimeSeries:
             os.makedirs(path)        
 
         startdatestr = lastdate.strftime('%Y-%m-%d')
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Writing %s from %s ...%.2f%% ' % \
                 (shm_name,startdatestr,0.0))
                 
@@ -329,7 +328,7 @@ class SharedDataTimeSeries:
         cy = 0        
         self.write_multithread(years,path)
         
-        if self.debug:
+        if os.environ['LOG_LEVEL']=='DEBUG':
             Logger.log.debug('Writing %s from %s ...%.2f%% %.2f sec!' % \
                 (shm_name,startdatestr,100*cy/ny,time.time()-tini))        
             
@@ -341,7 +340,6 @@ class SharedDataTimeSeries:
             # collect data
             data = [future.result() for future in futures]
         
-
     def write_thread(self,y, path):
         idx = self.data.index[self.data.index.year==y]
         dfyear = self.data.loc[idx,:].copy()
@@ -351,16 +349,20 @@ class SharedDataTimeSeries:
             dfyear = dfyear.reset_index()
 
             fpath_npy = path / (str(y)+'.npy')
-            np.save(str(fpath_npy),dfyear.values.astype(np.float64))
-            cols = ','.join(dfyear.columns)
-            fpath_csv = path / (str(y)+'.csv')
+            with open(fpath_npy, 'wb') as f:
+                np.save(f,dfyear.values.astype(np.float64))
+                f.flush()
+            
+            cols = ','.join(dfyear.columns)            
+            fpath_csv = path / (str(y)+'.csv')    
             with open(fpath_csv, 'w') as f:
                 f.write(cols)
+                f.flush()
+
             if self.sharedData.s3write:
                 S3Upload(fpath_npy)
                 S3Upload(fpath_csv)
             
-    
     def Broadcast(self,idx,col):
         SharedDataRealTime.Broadcast(
             self.sharedData,
